#
# spec file for package python-Logbook
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# Tests require a network connection
%bcond_with     test
Name:           python-Logbook
Version:        1.1.0
Release:        lp151.2.4
Summary:        A logging replacement for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/getlogbook/logbook
Source:         https://files.pythonhosted.org/packages/source/L/Logbook/Logbook-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
%if %{with test}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module execnet >= 1.0.9}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pyzmq}
BuildRequires:  %{python_module redis}
BuildRequires:  python-mock
%endif
Recommends:     python-Jinja2
Recommends:     python-SQLAlchemy
Recommends:     python-execnet >= 1.0.9
Recommends:     python-gevent
Recommends:     python-redis
Recommends:     python-pyzmq

%python_subpackages

%description
An alternative logging implementation for python.

%prep
%setup -q -n Logbook-%{version}
sed -i 's/\r$//' LICENSE
rm tests/*.pyc
rm -r tests/__pycache__

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
export CFLAGS="%{optflags}"
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES LICENSE 
%{python_sitearch}/*

%changelog
* Fri Sep  8 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to Version 1.1.0
  * Added a handler for Riemann (thanks Šarūnas Navickas)
  * Added a handler for Slack (thanks @jonathanng)
  * Colorizing mixin can now force coloring on or off (thanks @ayalash)
- Update to Version 1.0.1
  * Fix PushOver handler cropping (thanks Sébastien Celles)
* Fri Jan  6 2017 boris@steki.net
- Added support for timezones for log timestamp formatting (thanks Mattijs Ugen)
- Logbook has been a 0.x long enough to earn its 1.0.0 bump!
- Logbook now uses SemVer for its versioning scheme
- Various improvements to MailHandler and the usage of TLS/SMTP SSL (thanks Frazer McLean)
- Fix log colorizing on Windows (thanks Frazer McLean)
- Coverage reports using coveralls.io
- Dropped compatibility for Python 3.2. At this point we did not actually
  remove any code that supports it, but the continuous integration tests
  no longer check against it, and we will no longer fix compatibility issues with 3.2.
- Better coverage and tests on Windows (thanks Frazer McLean)
- Added enable() and disable() methods for loggers (thanks Frazer McLean)
- Many cleanups and overall project improvements (thanks Frazer McLean)
- Added logbook.utils.deprecated to automatically emit warnings when
  certain functions are called (Thanks Ayala Shachar)
- Added logbook.utils.suppressed_deprecations context to temporarily
  suppress deprecations (Thanks Ayala Shachar)
- Added logbook.utils.logged_if_slow to emit logs when certain operations
  exceed a time threshold (Thanks Ayala Shachar)
- Many PEP8 fixes and code cleanups (thanks Taranjeet Singh and Frazer McLean)
- TestHandler constructor now receives an optional force_heavy_init=True,
  forcing all records to heavy-initialize
- Windows-specific fixes and CI configuration (Thanks Frazer McLean)
- Several Unicode-specific fixes (Thanks Frazer McLean)
- Documentation cleanups
- Fix importing issue with SQLAlchemy ticketing handler
- Added TRACE log level for enabling logs below DEBUG
- Improved SQLAlchemy session management (thanks @fintan)
- Removed the bubble argument from NullHandler, preventing many future confusions
- Small bugfix supporting exc_info=False without breaking formatting
- Removed the global handler which was installed by default so far.
  The rationale is to ease adoption for 3rd party libraries who don’t want
  output to go to stderr by default. The old behavior can still be restored
  by setting the LOGBOOK_INSTALL_DEFAULT_HANDLER environment variable
- Added frame correction option, to properly mark log record origins (Thanks Roey Darwish)
- Fixed MailHandler infinite recursion bug (Thanks Tal Yalon)
- Fix support for gevent, along with various other fixes (Thanks Tal Yalon)
- Added Pushover handler (thanks @owo)
- Default logging format now includes seconds and microseconds (#110)
- Several fixes regarding possible deadlocks in log formatting (thanks Guy Rozendorn)
- Fixed packaging so that the speedups module now gets packaged by default (#122)
- ThreadedWrapperHandler now supports maxsize (#121) (thanks Ken Jung)
- Fixes in rotating handlers (thanks zhangliyong)
- Added Pushover handler (thanks Ossama W. Obeid)
- RedisHandler now supports lpush as an option (thanks Bruno Rocha)
- Restored Python 3.2 support (thanks @rnortman)
- NullHandlers now respect filters - allows to only drop/mute certain records (#73)
- redirect_logging now sets the legacy root logger’s level
  to DEBUG by default. This can be changed by specifying set_root_logger_level=False (#96)
- Added Redis handler (Thanks a lot @guillermo-carrasco for this PR)
- Fixed email encoding bug (Thanks Raphaël Vinot)
- Drop 2.5, 3.2 support, code cleanup
- The exc_info argument now accepts True, like in the standard logging modul
- Fixed Python 3.x compatibility, including speedups
- Dropped Python 2.4 support. Python 2.4 support caused a lot of
  hacks in the code and introduced duplication to the test code.
  In addition, it is impossible to cover 2.4-3.x with a single
  tox installation, which may introduce unwitting code breakage.
  Travis also does not support Python 2.4 so the chances of
  accidentally breaking this support were very high as it was...
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Apr 29 2013 speilicke@suse.com
- Package README and CHANGES
* Thu Apr 25 2013 prusnak@opensuse.org
- created package (version 0.4.1)
